==> mozjs91_91.10.0.orig.tar.xz: firefox-91.10.0/js/src/jit-test/tests/xdr/stencil-can-lazily-parse-mismatch.js <==
// |jit-test| skip-if: isLcovEnabled()
// Code coverage forces full-parse.

load(libdir + 'asserts.js');

const code = `var a = 10;`;

function testCompile(sourceIsLazy1, sourceIsLazy2,
                     forceFullParse1, forceFullParse2) {
  const stencil = compileToStencil(code, { sourceIsLazy: sourceIsLazy1,
                                           forceFullParse: forceFullParse1 });
  assertThrowsInstanceOf(() => {
    evalStencil(stencil, { sourceIsLazy: sourceIsLazy2,
                           forceFullParse: forceFullParse2 });
  }, Error);
}

function testOffThreadCompile(sourceIsLazy1, sourceIsLazy2,
                              forceFullParse1, forceFullParse2) {
  offThreadCompileToStencil(code, { sourceIsLazy: sourceIsLazy1,
                                    forceFullParse: forceFullParse1 });
  const stencil = finishOffThreadCompileToStencil();
  assertThrowsInstanceOf(() => {
    evalStencil(stencil, { sourceIsLazy: sourceIsLazy2,
                           forceFullParse: forceFullParse2 });
  }, Error);
}

function testXDR(sourceIsLazy1, sourceIsLazy2,
                 forceFullParse1, forceFullParse2) {
  const xdr = compileToStencilXDR(code, { sourceIsLazy: sourceIsLazy1,
                                          forceFullParse: forceFullParse1 });
  assertThrowsInstanceOf(() => {
    evalStencilXDR(xdr, { sourceIsLazy: sourceIsLazy2,
                          forceFullParse: forceFullParse2 });
  }, Error);
}

function testOffThreadXDR(sourceIsLazy1, sourceIsLazy2,
                          forceFullParse1, forceFullParse2) {
  const t = cacheEntry(code);
  evaluate(t, { sourceIsLazy: sourceIsLazy1,
                forceFullParse: forceFullParse1,
                saveIncrementalBytecode: true });
  offThreadDecodeScript(t, { sourceIsLazy: sourceIsLazy2,
                             forceFullParse: forceFullParse2 });
  assertThrowsInstanceOf(() => {
    runOffThreadDecodedScript();
  }, Error);
}

const optionsList = [
  [true, false, false, false],
  [false, true, false, false],
  [false, false, true, false],
  [false, false, false, true],
  [true, false, true, false],
  [false, true, false, true],
];

for (const options of optionsList) {
  testCompile(...options);
  if (helperThreadCount() > 0) {
    testOffThreadCompile(...options);
  }
  testXDR(...options);
  if (helperThreadCount() > 0) {
    testOffThreadXDR(...options);
  }
}

==> mozjs102_102.15.1.orig.tar.xz: firefox-102.15.1/js/src/jit-test/tests/xdr/stencil-can-lazily-parse-mismatch.js <==
// |jit-test| skip-if: isLcovEnabled()
// Code coverage forces full-parse.

load(libdir + 'asserts.js');

const code = `var a = 10;`;

function testCompile(sourceIsLazy1, sourceIsLazy2,
                     forceFullParse1, forceFullParse2) {
  const stencil = compileToStencil(code, { sourceIsLazy: sourceIsLazy1,
                                           forceFullParse: forceFullParse1 });
  // The laziness options are ignored for instantiation, and no error is thrown.
  evalStencil(stencil, { sourceIsLazy: sourceIsLazy2,
                         forceFullParse: forceFullParse2 });
}

function testOffThreadCompile(sourceIsLazy1, sourceIsLazy2,
                              forceFullParse1, forceFullParse2) {
  offThreadCompileToStencil(code, { sourceIsLazy: sourceIsLazy1,
                                    forceFullParse: forceFullParse1 });
  const stencil = finishOffThreadCompileToStencil();
  // The laziness options are ignored for instantiation, and no error is thrown.
  evalStencil(stencil, { sourceIsLazy: sourceIsLazy2,
                         forceFullParse: forceFullParse2 });
}

function testXDR(sourceIsLazy1, sourceIsLazy2,
                 forceFullParse1, forceFullParse2) {
  const xdr = compileToStencilXDR(code, { sourceIsLazy: sourceIsLazy1,
                                          forceFullParse: forceFullParse1 });
  // The compile options are ignored when decoding, and no error is thrown.
  evalStencilXDR(xdr, { sourceIsLazy: sourceIsLazy2,
                        forceFullParse: forceFullParse2 });
}

function testOffThreadXDR(sourceIsLazy1, sourceIsLazy2,
                          forceFullParse1, forceFullParse2) {
  const t = cacheEntry(code);
  evaluate(t, { sourceIsLazy: sourceIsLazy1,
                forceFullParse: forceFullParse1,
                saveIncrementalBytecode: true });

  // The compile options are ignored when decoding, and no error is thrown.
  offThreadDecodeStencil(t, { sourceIsLazy: sourceIsLazy2,
                             forceFullParse: forceFullParse2 });
  const stencil = finishOffThreadDecodeStencil();

  // The laziness options are ignored for instantiation, and no error is thrown.
  evalStencil(stencil, { sourceIsLazy: sourceIsLazy2,
                         forceFullParse: forceFullParse2 });
}

const optionsList = [
  [true, false, false, false],
  [false, true, false, false],
  [false, false, true, false],
  [false, false, false, true],
  [true, false, true, false],
  [false, true, false, true],
];

for (const options of optionsList) {
  testCompile(...options);
  if (helperThreadCount() > 0) {
    testOffThreadCompile(...options);
  }
  testXDR(...options);
  if (helperThreadCount() > 0) {
    testOffThreadXDR(...options);
  }
}
